@@ -33,7 +33,10 @@ def main():
         )
         exit(1)
 
-    os.system(str(scripts.get(args.script)))
+    script = str(scripts.get(args.script))
+    
+    print("> " + script)
+    os.system(script)
 
 
 if __name__ == "__main__":
